@@ -16,7 +16,7 @@ from sklearn.utils import Bunch
 from .utils import _get_data_dir, _get_dataset_info
 from ..utils import check_fs_subjid
 
-ANNOT = namedtuple('Surface', ('lh', 'rh'))
+SURFACE = namedtuple('Surface', ('lh', 'rh'))
 
 
 def fetch_cammoun2012(version='MNI152NLin2009aSym', data_dir=None, url=None,
@@ -137,7 +137,7 @@ def fetch_cammoun2012(version='MNI152NLin2009aSym', data_dir=None, url=None,
     if version == 'MNI152NLin2009aSym':
         keys += ['info']
     elif version in ('fslr32k', 'fsaverage', 'fsaverage5', 'fsaverage6'):
-        data = [ANNOT(*data[i:i + 2]) for i in range(0, len(data), 2)]
+        data = [SURFACE(*data[i:i + 2]) for i in range(0, len(data), 2)]
     else:
         data = [data[::2][i:i + 2] for i in range(0, len(data) // 2, 2)]
         # deal with the fact that last scale is split into three files :sigh:
@@ -212,7 +212,76 @@ def fetch_conte69(data_dir=None, url=None, resume=True, verbose=1):
         data[-1] = json.load(src)
 
     # bundle hemispheres together
-    data = [ANNOT(*data[:-1][i:i + 2]) for i in range(0, 6, 2)] + [data[-1]]
+    data = [SURFACE(*data[:-1][i:i + 2]) for i in range(0, 6, 2)] + [data[-1]]
+
+    return Bunch(**dict(zip(keys + ['info'], data)))
+
+
+def fetch_yerkes19(data_dir=None, url=None, resume=None, verbose=1):
+    """
+    Downloads files for Donahue et al., 2016 Yerkes19 template
+
+    Parameters
+    ----------
+    data_dir : str, optional
+        Path to use as data directory. If not specified, will check for
+        environmental variable 'NNT_DATA'; if that is not set, will use
+        `~/nnt-data` instead. Default: None
+    url : str, optional
+        URL from which to download data. Default: None
+    resume : bool, optional
+        Whether to attempt to resume partial download, if possible. Default:
+        True
+    verbose : int, optional
+        Modifies verbosity of download, where higher numbers mean more updates.
+        Default: 1
+
+    Returns
+    -------
+    filenames : :class:`sklearn.utils.Bunch`
+        Dictionary-like object with keys ['midthickness', 'inflated',
+        'vinflated'], where corresponding values are lists of filepaths to
+        downloaded template files.
+
+    References
+    ----------
+    https://balsa.wustl.edu/reference/show/976nz
+
+    Donahue, C. J., Sotiropoulos, S. N., Jbabdi, S., Hernandez-Fernandez, M.,
+    Behrens, T. E., Dyrby, T. B., ... & Glasser, M. F. (2016). Using diffusion
+    tractography to predict cortical connection strength and distance: a
+    quantitative comparison with tracers in the monkey. Journal of
+    Neuroscience, 36(25), 6758-6770.
+
+    Notes
+    -----
+    License: ???
+    """
+
+    dataset_name = 'tpl-yerkes19'
+    keys = ['midthickness', 'inflated', 'vinflated']
+
+    data_dir = _get_data_dir(data_dir=data_dir)
+    info = _get_dataset_info(dataset_name)
+    if url is None:
+        url = info['url']
+
+    opts = {
+        'uncompress': True,
+        'md5sum': info['md5'],
+        'move': '{}.tar.gz'.format(dataset_name)
+    }
+
+    filenames = [
+        'tpl-yerkes19/tpl-yerkes19_space-fsLR32k_{}.{}.surf.gii'
+        .format(res, hemi) for res in keys for hemi in ['L', 'R']
+    ]
+
+    data = _fetch_files(data_dir, files=[(f, url, opts) for f in filenames],
+                        resume=resume, verbose=verbose)
+
+    # bundle hemispheres together
+    data = [SURFACE(*data[i:i + 2]) for i in range(0, 6, 2)]
 
     return Bunch(**dict(zip(keys + ['info'], data)))
 
@@ -339,7 +408,7 @@ def fetch_fsaverage(version='fsaverage', data_dir=None, url=None, resume=True,
                             files=[(op.join(dataset_name, f), url, opts)
                                    for f in filenames])
 
-    data = [ANNOT(*data[i:i + 2]) for i in range(0, len(keys) * 2, 2)]
+    data = [SURFACE(*data[i:i + 2]) for i in range(0, len(keys) * 2, 2)]
 
     return Bunch(**dict(zip(keys, data)))
 
@@ -564,7 +633,7 @@ def fetch_schaefer2018(version='fsaverage', data_dir=None, url=None,
     data = _fetch_files(data_dir, files=files, resume=resume, verbose=verbose)
 
     if suffix == 'annot':
-        data = [ANNOT(*data[i:i + 2]) for i in range(0, len(keys) * 2, 2)]
+        data = [SURFACE(*data[i:i + 2]) for i in range(0, len(keys) * 2, 2)]
 
     return Bunch(**dict(zip(keys, data)))
 
@@ -610,6 +679,77 @@ def fetch_hcp_standards(data_dir=None, url=None, resume=True, verbose=1):
     return op.join(data_dir, dataset_name)
 
 
+def fetch_mmpall(version='fslr32k', data_dir=None, url=None, resume=True,
+                 verbose=1):
+    """
+    Downloads .label.gii files for Glasser et al., 2016 MMPAll atlas
+
+    Parameters
+    ----------
+    version : {'fslr32k'}
+        Specifies which surface annotation files should be matched to. Default:
+        'fslr32k'
+    data_dir : str, optional
+        Path to use as data directory. If not specified, will check for
+        environmental variable 'NNT_DATA'; if that is not set, will use
+        `~/nnt-data` instead. Default: None
+    url : str, optional
+        URL from which to download data. Default: None
+    resume : bool, optional
+        Whether to attempt to resume partial download, if possible. Default:
+        True
+    verbose : int, optional
+        Modifies verbosity of download, where higher numbers mean more updates.
+        Default: 1
+
+    Returns
+    -------
+    filenames : :class:`sklearn.utils.Bunch`
+        Namedtuple with fields ('lh', 'rh') corresponding to filepaths to
+        left/right hemisphere parcellation files
+
+    References
+    ----------
+    Glasser, M. F., Coalson, T. S., Robinson, E. C., Hacker, C. D., Harwell,
+    J., Yacoub, E., ... & Van Essen, D. C. (2016). A multi-modal parcellation
+    of human cerebral cortex. Nature, 536(7615), 171-178.
+
+    Notes
+    -----
+    License: https://www.humanconnectome.org/study/hcp-young-adult/document/
+    wu-minn-hcp-consortium-open-access-data-use-terms
+    """
+
+    versions = ['fslr32k']
+    if version not in versions:
+        raise ValueError('The version of Glasser et al., 2016 parcellation '
+                         'requested "{}" does not exist. Must be one of {}'
+                         .format(version, versions))
+
+    dataset_name = 'atl-mmpall'
+
+    data_dir = _get_data_dir(data_dir=data_dir)
+    info = _get_dataset_info(dataset_name)[version]
+    if url is None:
+        url = info['url']
+    opts = {
+        'uncompress': True,
+        'md5sum': info['md5'],
+        'move': '{}.tar.gz'.format(dataset_name)
+    }
+
+    hemispheres = ['L', 'R']
+    filenames = [
+        'atl-MMPAll_space-{}_hemi-{}_deterministic.label.gii'
+        .format(version, hemi) for hemi in hemispheres
+    ]
+
+    files = [(op.join(dataset_name, version, f), url, opts) for f in filenames]
+    data = _fetch_files(data_dir, files=files, resume=resume, verbose=verbose)
+
+    return SURFACE(*data)
+
+
 def fetch_voneconomo(data_dir=None, url=None, resume=True, verbose=1):
     """
     Fetches von-Economo Koskinas probabilistic FreeSurfer atlas
@@ -632,8 +772,7 @@ def fetch_voneconomo(data_dir=None, url=None, resume=True, verbose=1):
     Returns
     -------
     filenames : :class:`sklearn.utils.Bunch`
-        Dictionary-like object with keys of format '{}Parcels{}Networks' where
-        corresponding values are the left/right hemisphere annotation files
+        Dictionary-like object with keys ['gcs', 'ctab', 'info']
 
     References
     ----------
@@ -664,6 +803,92 @@ def fetch_voneconomo(data_dir=None, url=None, resume=True, verbose=1):
     ] + ['atl-vonEconomoKoskinas_info.csv']
     files = [(op.join(dataset_name, f), url, opts) for f in filenames]
     data = _fetch_files(data_dir, files=files, resume=resume, verbose=verbose)
-    data = [ANNOT(*data[:-1:2])] + [ANNOT(*data[1:-1:2])] + [data[-1]]
+    data = [SURFACE(*data[:-1:2])] + [SURFACE(*data[1:-1:2])] + [data[-1]]
+
+    return Bunch(**dict(zip(keys, data)))
+
+
+def fetch_civet(density='41k', version='v1', data_dir=None, url=None,
+                resume=True, verbose=1):
+    """
+    Fetches CIVET surface files
+
+    Parameters
+    ----------
+    density : {'41k', '164k'}, optional
+        Which density of the CIVET-space geometry files to fetch. The
+        high-resolution '164k' surface only exists for version 'v2'
+    version : {'v1, 'v2'}, optional
+        Which version of the CIVET surfaces to use. Default: 'v2'
+    data_dir : str, optional
+        Path to use as data directory. If not specified, will check for
+        environmental variable 'NNT_DATA'; if that is not set, will use
+        `~/nnt-data` instead. Default: None
+    url : str, optional
+        URL from which to download data. Default: None
+    resume : bool, optional
+        Whether to attempt to resume partial download, if possible. Default:
+        True
+    verbose : int, optional
+        Modifies verbosity of download, where higher numbers mean more updates.
+        Default: 1
+
+    Returns
+    -------
+    filenames : :class:`sklearn.utils.Bunch`
+        Dictionary-like object with keys ['mid', 'white'] containing geometry
+        files for CIVET surface. Note for version 'v1' the 'mid' and 'white'
+        files are identical.
+
+    References
+    ----------
+    Y. Ad-Dab’bagh, O. Lyttelton, J.-S. Muehlboeck, C. Lepage, D. Einarson, K.
+    Mok, O. Ivanov, R. Vincent, J. Lerch, E. Fombonne, A. C. Evans, The CIVET
+    image-processing environment: A fully automated comprehensive pipeline for
+    anatomical neuroimaging research. Proceedings of the 12th Annual Meeting of
+    the Organization for Human Brain Mapping (2006).
+
+    Notes
+    -----
+    License: https://github.com/aces/CIVET_Full_Project/blob/master/LICENSE
+    """
+
+    densities = ['41k', '164k']
+    if density not in densities:
+        raise ValueError('The density of CIVET requested "{}" does not exist. '
+                         'Must be one of {}'.format(density, densities))
+    versions = ['v1', 'v2']
+    if version not in versions:
+        raise ValueError('The version of CIVET requested "{}" does not exist. '
+                         'Must be one of {}'.format(version, versions))
+
+    if version == 'v1' and density == '164k':
+        raise ValueError('The "164k" density CIVET surface only exists for '
+                         'version "v2"')
+
+    dataset_name = 'tpl-civet'
+    keys = ['mid', 'white']
+
+    data_dir = _get_data_dir(data_dir=data_dir)
+    info = _get_dataset_info(dataset_name)[version]['civet{}'.format(density)]
+    if url is None:
+        url = info['url']
+
+    opts = {
+        'uncompress': True,
+        'md5sum': info['md5'],
+        'move': '{}.tar.gz'.format(dataset_name)
+    }
+    filenames = [
+        op.join(dataset_name, version, 'civet{}'.format(density),
+                'tpl-civet_space-ICBM152_hemi-{}_den-{}_{}.obj'
+                .format(hemi, density, surf))
+        for surf in keys for hemi in ['L', 'R']
+    ]
+
+    data = _fetch_files(data_dir, resume=resume, verbose=verbose,
+                        files=[(f, url, opts) for f in filenames])
+
+    data = [SURFACE(*data[i:i + 2]) for i in range(0, len(keys) * 2, 2)]
 
     return Bunch(**dict(zip(keys, data)))
