@@ -6,9 +6,12 @@ Functions for performing statistical preprocessing and analyses
 import warnings
 
 import numpy as np
+from tqdm import tqdm
+from itertools import combinations
 from scipy import optimize, spatial, special, stats as sstats
 from scipy.stats.stats import _chk2_asarray
 from sklearn.utils.validation import check_random_state
+from sklearn.linear_model import LinearRegression
 
 from . import utils
 
@@ -420,7 +423,7 @@ def permtest_pearsonr(a, b, axis=0, n_perm=1000, resamples=None, seed=0):
     return true_corr, pvals
 
 
-def efficient_pearsonr(a, b):
+def efficient_pearsonr(a, b, ddof=1, nan_policy='propagate'):
     """
     Computes correlation of matching columns in `a` and `b`
 
@@ -429,6 +432,13 @@ def efficient_pearsonr(a, b):
     a,b : array_like
         Sample observations. These arrays must have the same length and either
         an equivalent number of columns or be broadcastable
+    ddof : int, optional
+        Degrees of freedom correction in the calculation of the standard
+        deviation. Default: 1
+    nan_policy : bool, optional
+        Defines how to handle when input contains nan. 'propagate' returns nan,
+        'raise' throws an error, 'omit' performs the calculations ignoring nan
+        values. Default: 'propagate'
 
     Returns
     -------
@@ -437,6 +447,11 @@ def efficient_pearsonr(a, b):
     pval : float or numpy.ndarray
         Two-tailed p-values
 
+    Notes
+    -----
+    If either input contains nan and nan_policy is set to 'omit', both arrays
+    will be masked to omit the nan entries.
+
     Examples
     --------
     >>> from netneurotools import datasets, stats
@@ -449,9 +464,7 @@ def efficient_pearsonr(a, b):
 
     Calculate both correlations simultaneously:
 
-    >>> x = np.column_stack((x1, x2))
-    >>> y = np.column_stack((y1, y2))
-    >>> stats.efficient_pearsonr(x, y)
+    >>> stats.efficient_pearsonr(np.c_[x1, x2], np.c_[y1, y2])
     (array([0.10032565, 0.79961189]), array([3.20636135e-01, 1.97429944e-23]))
     """
 
@@ -462,17 +475,36 @@ def efficient_pearsonr(a, b):
     if a.size == 0 or b.size == 0:
         return np.nan, np.nan
 
+    if nan_policy not in ('propagate', 'raise', 'omit'):
+        raise ValueError(f'Value for nan_policy "{nan_policy}" not allowed')
+
     a, b = a.reshape(len(a), -1), b.reshape(len(b), -1)
     if (a.shape[1] != b.shape[1]):
         a, b = np.broadcast_arrays(a, b)
 
+    mask = np.logical_or(np.isnan(a), np.isnan(b))
+    if nan_policy == 'raise' and np.any(mask):
+        raise ValueError('Input cannot contain NaN when nan_policy is "omit"')
+    elif nan_policy == 'omit':
+        # avoid making copies of the data, if possible
+        a = np.ma.masked_array(a, mask, copy=False, fill_value=np.nan)
+        b = np.ma.masked_array(b, mask, copy=False, fill_value=np.nan)
+
     with np.errstate(invalid='ignore'):
-        corr = sstats.zscore(a, ddof=1) * sstats.zscore(b, ddof=1)
-    corr = np.sum(corr, axis=0) / (len(a) - 1)
+        corr = (sstats.zscore(a, ddof=ddof, nan_policy=nan_policy)
+                * sstats.zscore(b, ddof=ddof, nan_policy=nan_policy))
+
+    sumfunc, n_obs = np.sum, len(a)
+    if nan_policy == 'omit':
+        corr = corr.filled(np.nan)
+        sumfunc = np.nansum
+        n_obs = np.squeeze(np.sum(np.logical_not(np.isnan(corr)), axis=0))
+
+    corr = sumfunc(corr, axis=0) / (n_obs - 1)
     corr = np.squeeze(np.clip(corr, -1, 1)) / 1
 
     # taken from scipy.stats
-    ab = (len(a) / 2) - 1
+    ab = (n_obs / 2) - 1
     prob = 2 * special.btdtr(ab, ab, 0.5 * (1 - np.abs(corr)))
 
     return corr, prob
@@ -582,7 +614,7 @@ def gen_spinsamples(coords, hemiid, n_rotate=1000, check_duplicates=True,
         array([[0],
                [0],
                [2],
-               [3]], dtype=int32)
+               [3]])
 
     While this is reasonable in most circumstances, if you feel incredibly
     strongly about having a perfect "permutation" (i.e., all indices appear
@@ -594,13 +626,13 @@ def gen_spinsamples(coords, hemiid, n_rotate=1000, check_duplicates=True,
         array([[1],
                [0],
                [2],
-               [3]], dtype=int32)
+               [3]])
         >>> nnstats.gen_spinsamples(coords, hemi, n_rotate=1, seed=1,
         ...                         method='hungarian', check_duplicates=False)
         array([[0],
                [1],
                [2],
-               [3]], dtype=int32)
+               [3]])
 
     Note that setting this parameter may increase the runtime of the function
     (especially for `method='hungarian'`). Refer to [ST1]_ for information on
@@ -662,18 +694,16 @@ def gen_spinsamples(coords, hemiid, n_rotate=1000, check_duplicates=True,
         raise ValueError('Provided `coords` and `hemiid` must have the same '
                          'length. Provided lengths: coords = {}, hemiid = {}'
                          .format(len(coords), len(hemiid)))
-    if np.max(hemiid) != 1 or np.min(hemiid) != 0:
+    if np.max(hemiid) > 1 or np.min(hemiid) < 0:
         raise ValueError('Hemiid must have values in {0, 1} denoting left and '
                          'right hemisphere coordinates, respectively. '
                          + 'Provided array contains values: {}'
                          .format(np.unique(hemiid)))
 
     # empty array to store resampling indices
-    # int32 should be enough; if you're ever providing `coords` with more than
-    # 2147483647 rows please reconsider your life choices
-    spinsamples = np.zeros((len(coords), n_rotate), dtype='int32')
+    spinsamples = np.zeros((len(coords), n_rotate), dtype=int)
     cost = np.zeros((len(coords), n_rotate))
-    inds = np.arange(len(coords), dtype='int32')
+    inds = np.arange(len(coords), dtype=int)
 
     # generate rotations and resampling array!
     msg, warned = '', False
@@ -692,6 +722,8 @@ def gen_spinsamples(coords, hemiid, n_rotate=1000, check_duplicates=True,
             for h, rot in enumerate(_gen_rotation(seed=seed)):
                 hinds = (hemiid == h)
                 coor = coords[hinds]
+                if len(coor) == 0:
+                    continue
 
                 # if we need an "exact" mapping (i.e., each node needs to be
                 # assigned EXACTLY once) then we have to calculate the full
@@ -755,3 +787,141 @@ def gen_spinsamples(coords, hemiid, n_rotate=1000, check_duplicates=True,
         return spinsamples, cost
 
     return spinsamples
+
+
+def get_dominance_stats(X, y, use_adjusted_r_sq=True, verbose=False):
+    """
+    Returns the dominance analysis statistics for multilinear regression.
+
+    This is a rewritten & simplified version of [DA1]_. It is briefly
+    tested against the original package, but still in early stages.
+    Please feel free to report any bugs.
+
+    Warning: Still work-in-progress. Parameters might change!
+
+    Parameters
+    ----------
+    X : (N, M) array_like
+        Input data
+    y : (N,) array_like
+        Target values
+    use_adjusted_r_sq : bool, optional
+        Whether to use adjusted r squares. Default: True
+    verbose : bool, optional
+        Whether to print debug messages. Default: False
+
+    Returns
+    -------
+    model_metrics : dict
+        The dominance metrics, currently containing `individual_dominance`,
+        `partial_dominance`, `total_dominance`, and `full_r_sq`.
+    model_r_sq : dict
+        Contains all model r squares
+
+    Notes
+    -----
+    Example usage
+
+    .. code:: python
+
+        from netneurotools.stats import get_dominance_stats
+        from sklearn.datasets import load_boston
+        X, y = load_boston(return_X_y=True)
+        model_metrics, model_r_sq = get_dominance_stats(X, y)
+
+    To compare with [DA1]_, use `use_adjusted_r_sq=False`
+
+    .. code:: python
+
+        from dominance_analysis import Dominance_Datasets
+        from dominance_analysis import Dominance
+        boston_dataset=Dominance_Datasets.get_boston()
+        dominance_regression=Dominance(data=boston_dataset,
+                                       target='House_Price',objective=1)
+        incr_variable_rsquare=dominance_regression.incremental_rsquare()
+        dominance_regression.dominance_stats()
+
+    References
+    ----------
+    .. [DA1] https://github.com/dominance-analysis/dominance-analysis
+
+    """
+
+    # this helps to remove one element from a tuple
+    def remove_ret(tpl, elem):
+        lst = list(tpl)
+        lst.remove(elem)
+        return tuple(lst)
+
+    # sklearn linear regression wrapper
+    def get_reg_r_sq(X, y):
+        lin_reg = LinearRegression()
+        lin_reg.fit(X, y)
+        yhat = lin_reg.predict(X)
+        SS_Residual = sum((y - yhat) ** 2)
+        SS_Total = sum((y - np.mean(y)) ** 2)
+        r_squared = 1 - (float(SS_Residual)) / SS_Total
+        adjusted_r_squared = 1 - (1 - r_squared) * \
+            (len(y) - 1) / (len(y) - X.shape[1] - 1)
+        if use_adjusted_r_sq:
+            return adjusted_r_squared
+        else:
+            return r_squared
+
+    # generate all predictor combinations in list (num of predictors) of lists
+    n_predictor = X.shape[-1]
+    # n_comb_len_group = n_predictor - 1
+    predictor_combs = [list(combinations(range(n_predictor), i))
+                       for i in range(1, n_predictor + 1)]
+    if verbose:
+        print(f"[Dominance analysis] Generated \
+              {len([v for i in predictor_combs for v in i])} combinations")
+
+    # get all r_sq's
+    model_r_sq = dict()
+    for len_group in tqdm(predictor_combs, desc='num-of-predictor loop',
+                          disable=not verbose):
+        for idx_tuple in tqdm(len_group, desc='insider loop',
+                              disable=not verbose):
+            r_sq = get_reg_r_sq(X[:, idx_tuple], y)
+            model_r_sq[idx_tuple] = r_sq
+    if verbose:
+        print(f"[Dominance analysis] Acquired {len(model_r_sq)} r^2's")
+
+    # getting all model metrics
+    model_metrics = dict([])
+
+    # individual dominance
+    individual_dominance = []
+    for i_pred in range(n_predictor):
+        individual_dominance.append(model_r_sq[(i_pred,)])
+    individual_dominance = np.array(individual_dominance).reshape(1, -1)
+    model_metrics["individual_dominance"] = individual_dominance
+
+    # partial dominance
+    partial_dominance = [[] for _ in range(n_predictor - 1)]
+    for i_len in range(n_predictor - 1):
+        i_len_combs = list(combinations(range(n_predictor), i_len + 2))
+        for j_node in range(n_predictor):
+            j_node_sel = [v for v in i_len_combs if j_node in v]
+            reduced_list = [remove_ret(comb, j_node) for comb in j_node_sel]
+            diff_values = [
+                model_r_sq[j_node_sel[i]] - model_r_sq[reduced_list[i]]
+                for i in range(len(reduced_list))]
+            partial_dominance[i_len].append(np.mean(diff_values))
+
+    # save partial dominance
+    partial_dominance = np.array(partial_dominance)
+    model_metrics["partial_dominance"] = partial_dominance
+    # get total dominance
+    total_dominance = np.mean(
+        np.r_[individual_dominance, partial_dominance], axis=0)
+    # test and save total dominance
+    assert np.allclose(total_dominance.sum(),
+                       model_r_sq[tuple(range(n_predictor))]), \
+           "Sum of total dominance is not equal to full r square!"
+    model_metrics["total_dominance"] = total_dominance
+    # save full r^2
+    model_metrics["full_r_sq"] = model_r_sq[tuple(range(n_predictor))]
+
+    return model_metrics, model_r_sq
